@@ -49,14 +49,14 @@ def find(host, port, calling_ae_title, called_ae_title, level, keys, decode_uids
     
     sop_class = getattr(
         odil.registry,
-        "{}RootQueryRetrieveInformationModelFIND".format(level.capitalize()))
+        "{}RootQueryRetrieveInformationModelFind".format(level.capitalize()))
     
     find_pc = odil.AssociationParameters.PresentationContext(
         1, sop_class,
         [
             odil.registry.ImplicitVRLittleEndian,
             odil.registry.ExplicitVRLittleEndian
-        ], True, False
+        ], odil.AssociationParameters.PresentationContext.Role.SCU
     )
     
     association = odil.Association()
