@@ -30,67 +30,41 @@ FindSCU
     // Nothing else.
 }
 
-FindSCU
-::~FindSCU()
-{
-    // Nothing to do
-}
-
 void
 FindSCU
-::find(DataSet const & query, Callback callback) const
+::find(std::shared_ptr<DataSet> query, Callback callback) const
 {
-    message::CFindRequest request(
+    auto request = std::make_shared<message::CFindRequest>(
         this->_association.next_message_id(),
         this->_affected_sop_class, message::Message::Priority::MEDIUM, query);
     this->_find(request, callback);
 }
 
-void
-FindSCU
-::find(DataSet && query, Callback callback) const
+void _accumulate(
+    std::vector<std::shared_ptr<DataSet>> & data_sets,
+    std::shared_ptr<DataSet> data_set)
 {
-    message::CFindRequest request(
-        this->_association.next_message_id(),
-        this->_affected_sop_class, message::Message::Priority::MEDIUM,
-        std::move(query));
-    this->_find(request, callback);
+    data_sets.push_back(data_set);
 }
 
-void _accumulate(std::vector<DataSet> & data_sets, DataSet && data_set)
-{
-    data_sets.push_back(std::move(data_set));
-}
-
-std::vector<DataSet>
+Value::DataSets
 FindSCU
-::find(DataSet const & query) const
+::find(std::shared_ptr<DataSet> query) const
 {
-    std::vector<DataSet> result;
-    auto callback = [&result](DataSet && dataset) {
-        result.push_back(std::move(dataset));
+    Value::DataSets result;
+    auto callback = [&result](std::shared_ptr<DataSet> dataset) {
+        result.push_back(dataset);
     };
     this->find(query, callback);
 
     return result;
 }
 
-std::vector<DataSet>
-FindSCU
-::find(DataSet && query) const
-{
-    std::vector<DataSet> result;
-    auto callback = [&result](DataSet && dataset) {
-        result.push_back(std::move(dataset));
-    };
-    this->find(std::move(query), callback);
-
-    return result;
-}
-
 void
 FindSCU
-::_find(message::CFindRequest const & request, Callback callback) const
+::_find(
+    std::shared_ptr<message::CFindRequest const> request,
+    Callback callback) const
 {
     this->_association.send_message(request, this->_affected_sop_class);
 
@@ -99,40 +73,40 @@ FindSCU
     while(!done)
     {
         // FIXME: include progress callback
-        message::CFindResponse response =
-            this->_association.receive_message();
+        auto response = std::make_shared<message::CFindResponse>(
+            this->_association.receive_message());
 
-        if(response.get_message_id_being_responded_to() != request.get_message_id())
+        if(response->get_message_id_being_responded_to() != request->get_message_id())
         {
             std::ostringstream message;
             message << "DIMSE: Unexpected Response MsgId: "
-                    << response.get_message_id_being_responded_to()
-                    << "(expected: " << request.get_message_id() << ")";
+                    << response->get_message_id_being_responded_to()
+                    << "(expected: " << request->get_message_id() << ")";
             throw Exception(message.str());
         }
-        if(response.has_affected_sop_class_uid() &&
-           response.get_affected_sop_class_uid() != request.get_affected_sop_class_uid())
+        if(response->has_affected_sop_class_uid() &&
+           response->get_affected_sop_class_uid() != request->get_affected_sop_class_uid())
         {
             std::ostringstream message;
             message << "DIMSE: Unexpected Response Affected SOP Class UID: "
-                    << response.get_affected_sop_class_uid()
-                    << " (expected: " << request.get_affected_sop_class_uid() << ")";
+                    << response->get_affected_sop_class_uid()
+                    << " (expected: " << request->get_affected_sop_class_uid() << ")";
             throw Exception(message.str());
         }
 
-        if(message::Response::is_warning(response.get_status()))
+        if(message::Response::is_warning(response->get_status()))
         {
-            ODIL_LOG(WARN) << "C-FIND response status: " << response.get_status();
+            ODIL_LOG(warning) << "C-FIND response status: " << response->get_status();
         }
-        else if(message::Response::is_failure(response.get_status()))
+        else if(message::Response::is_failure(response->get_status()))
         {
-            ODIL_LOG(ERROR) << "C-FIND response status: " << response.get_status();
+            ODIL_LOG(error) << "C-FIND response status: " << response->get_status();
         }
 
-        done = !response.is_pending();
+        done = !response->is_pending();
         if(!done)
         {
-            callback(std::move(response.get_data_set()));
+            callback(response->get_data_set());
         }
     }
 }
