@@ -60,6 +60,85 @@ Writer
     }
 }
 
+std::size_t
+Writer
+::size(odil::Tag const &, bool, ItemEncoding, bool)
+{
+    return 4;
+}
+
+std::size_t
+Writer
+::size(
+    odil::VR vr, odil::Value const & value, bool explicit_vr,
+    ItemEncoding item_encoding, bool use_group_length)
+{
+    SizeVisitor const visitor(vr, explicit_vr, item_encoding, use_group_length);
+    return apply_visitor(visitor, value);
+}
+
+std::size_t
+Writer
+::size(
+    odil::Element const & element, bool explicit_vr, ItemEncoding item_encoding,
+    bool use_group_length)
+{
+    std::size_t const vr = explicit_vr ? 2 : 0;
+    std::size_t const vl = 
+        explicit_vr
+        ? (
+            (
+                element.vr == odil::VR::OB || element.vr == odil::VR::OW
+                || element.vr == odil::VR::OF || element.vr == odil::VR::SQ
+                || element.vr == odil::VR::UT || element.vr == odil::VR::UN)
+            ? 2+4 /* PS3.5, table 7.1-1*/
+            : 2 /* PS3.5, table 7.1-2*/ )
+        : 4 /* PS 3.5, table 7.1-3 */;
+    
+    auto const value = Writer::size(
+        element.vr, element.get_value(), explicit_vr, item_encoding,
+        use_group_length);
+    
+    return vr+vl+value;
+}
+
+std::size_t
+Writer
+::size(
+    odil::DataSet const & data_set, bool explicit_vr,
+    ItemEncoding item_encoding, bool use_group_length)
+{
+    std::size_t size=0;
+    
+    uint16_t group = 0xffff;
+    for(auto && item: data_set)
+    {
+        auto const & tag = item.first;
+        auto const & element = item.second;
+        
+        size += Writer::size(tag, explicit_vr, item_encoding, use_group_length);
+        size += Writer::size(
+            element, explicit_vr, item_encoding, use_group_length);
+        
+        if(tag.group != group)
+        {
+            group = tag.group;
+            auto const write_group_length = (
+                group == 0 || group == 2 ||
+                (use_group_length && group != 4 && group != 6));
+            if(write_group_length)
+            {
+                // Tag
+                size += 4;
+                // Value (UL)
+                size += 4;
+            }
+        }
+    }
+    
+    return size;
+}
+
 Writer
 ::Writer(
     std::ostream & stream,
@@ -90,46 +169,56 @@ void
 Writer
 ::write_data_set(std::shared_ptr<DataSet const> data_set) const
 {
-    // Build a map of the different group in order to handle
-    // Group Length elements
-    std::map<uint16_t, std::vector<Tag>> groups;
-    for(auto const & item: *data_set)
-    {
-        auto const & tag = item.first;
-        groups[tag.group].push_back(tag);
-    }
-
-    for(auto const & groups_it: groups)
-    {
-        std::ostringstream group_stream;
-        Writer group_writer(
-            group_stream, this->byte_ordering, this->explicit_vr,
-            this->item_encoding, this->use_group_length);
-
-        for(auto const & tag: groups_it.second)
-        {
-            group_writer.write_tag(tag);
-            group_writer.write_element((*data_set)[tag]);
-        }
-
+    // Utility function checking whether the group length should be written
+    auto write_group_length = [](bool use_group_length, uint16_t group) {
         // Write group length if necessary
         // Mandatory for group 0: PS3.7, 9.3, 10.3, and E.1
         // Mandatory for group 2: PS3.10, 7.1
         // Forbidden for groups 4 and 6?
-        auto const write_group_length = (
-            groups_it.first == 0 || groups_it.first == 2 ||
-            (this->use_group_length && groups_it.first != 4 && groups_it.first != 6));
-        if(write_group_length)
+        return
+            group == 0 || group == 2 ||
+            (use_group_length && group != 4 && group != 6);
+    };
+    
+    // Build a map of the group lengths
+    std::map<uint16_t, odil::Value::Integer> group_lengths;
+    for(auto && item: *data_set)
+    {
+        if(write_group_length(this->use_group_length, item.first.group))
+        {
+            auto const size = 
+                Writer::size(
+                    item.first, this->explicit_vr, this->item_encoding,
+                    this->use_group_length)
+                + Writer::size(
+                    item.second, this->explicit_vr, this->item_encoding,
+                    this->use_group_length);
+            group_lengths.insert({item.first.group, 0}).first->second += size;
+        }
+    }
+    
+    // Write the data set items. When a new group appears, write its group
+    // length if required.
+    uint16_t previous_element = 0xffff;
+    for(auto && item: *data_set)
+    {
+        auto const & tag = item.first;
+        auto const group = tag.group;
+        auto const element = tag.element;
+        if(
+            element < previous_element
+            && write_group_length(this->use_group_length, group))
         {
             // Group length: (gggg,0000) UL Type=3 VM=1
-            this->write_tag(Tag(groups_it.first, 0));
+            this->write_tag(Tag(tag.group, 0));
             this->write_element(
-                Element(Value::Integers({group_stream.tellp()}), VR::UL));
+                Element(Value::Integers({group_lengths.at(group)}), VR::UL));
         }
-
-        // Write group data to main stream
-        std::string const group_data = group_stream.str();
-        this->stream.write(&group_data[0], group_data.size());
+        previous_element = element;
+        
+        this->write_tag(item.first);
+        this->write_element(item.second);
+        
         if(!this->stream)
         {
             throw Exception("Could not write to stream");
@@ -141,8 +230,8 @@ void
 Writer
 ::write_tag(Tag const & tag) const
 {
-    this->write_binary(tag.group, this->stream, this->byte_ordering);
-    this->write_binary(tag.element, this->stream, this->byte_ordering);
+    Writer::write_binary(tag.group, this->stream, this->byte_ordering);
+    Writer::write_binary(tag.element, this->stream, this->byte_ordering);
 }
 
 void
@@ -161,16 +250,6 @@ Writer
         }
     }
 
-    // Write value to a sub-stream
-    std::ostringstream value_stream;
-    if(!element.get_value().empty())
-    {
-        Visitor const visitor(
-            value_stream, vr, this->byte_ordering, this->explicit_vr,
-            this->item_encoding, this->use_group_length);
-        apply_visitor(visitor, element.get_value());
-    }
-
     // Write VL
     if(this->explicit_vr)
     {
@@ -178,7 +257,8 @@ Writer
            vr == VR::OV || vr == VR::OW || vr == VR::SQ || vr == VR::UC || 
            vr == VR::UR || vr == VR::UT || vr == VR::UN)
         {
-            this->write_binary(uint16_t(0), this->stream, this->byte_ordering);
+            Writer::write_binary(
+                uint16_t(0), this->stream, this->byte_ordering);
 
             uint32_t vl;
             if(vr == VR::SQ &&
@@ -192,23 +272,37 @@ Writer
             }
             else
             {
-               vl = value_stream.tellp();
+                vl = Writer::size(
+                    vr, element.get_value(), this->explicit_vr,
+                    this->item_encoding, this->use_group_length);
             }
-            this->write_binary(vl, this->stream, this->byte_ordering);
+            Writer::write_binary(vl, this->stream, this->byte_ordering);
         }
         else
         {
-            this->write_binary(
-                uint16_t(value_stream.tellp()), this->stream, this->byte_ordering);
+            auto const vl = Writer::size(
+                vr, element.get_value(), this->explicit_vr, this->item_encoding,
+                this->use_group_length);
+            Writer::write_binary(
+                uint16_t(vl), this->stream, this->byte_ordering);
         }
     }
     else
     {
-        this->write_binary(
-            uint32_t(value_stream.tellp()), this->stream, this->byte_ordering);
+        auto const vl = Writer::size(
+            vr, element.get_value(), this->explicit_vr, this->item_encoding,
+            this->use_group_length);
+        Writer::write_binary(
+            uint32_t(vl), this->stream, this->byte_ordering);
     }
 
-    this->stream.write(value_stream.str().c_str(), value_stream.tellp());
+    if(!element.get_value().empty())
+    {
+        WriteVisitor const visitor(
+            this->stream, vr, this->byte_ordering, this->explicit_vr,
+            this->item_encoding, this->use_group_length);
+        apply_visitor(visitor, element.get_value());
+    }
     if(!this->stream)
     {
         throw Exception("Could not write to stream");
@@ -306,8 +400,8 @@ Writer
     data_set_writer.write_data_set(data_set);
 }
 
-Writer::Visitor
-::Visitor(
+Writer::WriteVisitor
+::WriteVisitor(
     std::ostream & stream, VR vr,
     ByteOrdering byte_ordering, bool explicit_vr, Writer::ItemEncoding item_encoding,
     bool use_group_length)
@@ -317,8 +411,8 @@ Writer::Visitor
     // Nothing else
 }
 
-Writer::Visitor::result_type
-Writer::Visitor
+Writer::WriteVisitor::result_type
+Writer::WriteVisitor
 ::operator()(Value::Integers const & value) const
 {
     if(this->vr == VR::IS)
@@ -379,8 +473,8 @@ Writer::Visitor
     }
 }
 
-Writer::Visitor::result_type
-Writer::Visitor
+Writer::WriteVisitor::result_type
+Writer::WriteVisitor
 ::operator()(Value::Reals const & value) const
 {
     if(this->vr == VR::DS)
@@ -446,8 +540,8 @@ Writer::Visitor
     }
 }
 
-Writer::Visitor::result_type
-Writer::Visitor
+Writer::WriteVisitor::result_type
+Writer::WriteVisitor
 ::operator()(Value::Strings const & value) const
 {
     if(this->vr == VR::AT)
@@ -467,25 +561,16 @@ Writer::Visitor
     }
 }
 
-Writer::Visitor::result_type
-Writer::Visitor
+Writer::WriteVisitor::result_type
+Writer::WriteVisitor
 ::operator()(Value::DataSets const & value) const
 {
-    // Write all items to a sub-stream
-    std::ostringstream sequence_stream;
     Writer sequence_writer(
-        sequence_stream, this->byte_ordering, this->explicit_vr,
+        this->stream, this->byte_ordering, this->explicit_vr,
         this->item_encoding, this->use_group_length);
 
     for(auto const & item: value)
     {
-        // Write item to a sub-stream
-        std::ostringstream item_stream;
-        Writer item_writer(
-            item_stream, this->byte_ordering, this->explicit_vr,
-            this->item_encoding, this->use_group_length);
-        item_writer.write_data_set(item);
-
         // Beginning of item
         sequence_writer.write_tag(registry::Item);
 
@@ -493,17 +578,19 @@ Writer::Visitor
         uint32_t item_length;
         if(this->item_encoding == ItemEncoding::ExplicitLength)
         {
-            item_length = item_stream.tellp();
+            item_length = Writer::size(
+                *item, this->explicit_vr, this->item_encoding,
+                this->use_group_length);
         }
         else
         {
             item_length = 0xffffffff;
         }
-        Writer::write_binary(item_length, sequence_stream, this->byte_ordering);
+        Writer::write_binary(item_length, this->stream, this->byte_ordering);
 
         // Data set
-        sequence_stream.write(item_stream.str().c_str(), item_stream.tellp());
-        if(!sequence_stream)
+        sequence_writer.write_data_set(item);
+        if(!this->stream)
         {
             throw Exception("Could not write to stream");
         }
@@ -512,7 +599,7 @@ Writer::Visitor
         if(this->item_encoding == ItemEncoding::UndefinedLength)
         {
             sequence_writer.write_tag(registry::ItemDelimitationItem);
-            Writer::write_binary(uint32_t(0), sequence_stream, this->byte_ordering);
+            Writer::write_binary(uint32_t(0), this->stream, this->byte_ordering);
         }
     }
 
@@ -520,18 +607,17 @@ Writer::Visitor
     if(this->item_encoding == ItemEncoding::UndefinedLength)
     {
         sequence_writer.write_tag(registry::SequenceDelimitationItem);
-        Writer::write_binary(uint32_t(0), sequence_stream, this->byte_ordering);
+        Writer::write_binary(uint32_t(0), this->stream, this->byte_ordering);
     }
 
-    this->stream.write(sequence_stream.str().c_str(), sequence_stream.tellp());
     if(!this->stream)
     {
         throw Exception("Could not write to stream");
     }
 }
 
-Writer::Visitor::result_type
-Writer::Visitor
+Writer::WriteVisitor::result_type
+Writer::WriteVisitor
 ::operator()(Value::Binary const & value) const
 {
     if(value.empty())
@@ -591,40 +677,39 @@ Writer::Visitor
     }
 }
 
-template<typename T>
 void
-Writer::Visitor
-::write_strings(T const & sequence, char padding) const
+Writer::WriteVisitor
+::write_strings(Value::Strings const & sequence, char padding) const
 {
     if(sequence.empty())
     {
         return;
     }
 
-    auto const stream_begin = this->stream.tellp();
+    std::size_t size = 0;
 
-    auto last_element_it = --sequence.end();
-    for(auto it = sequence.begin(); it!= sequence.end(); ++it)
+    auto const last_element_it = --sequence.end();
+    for(auto it = sequence.begin(); it != sequence.end(); ++it)
     {
-        this->stream << *it;
+        this->stream.write(it->data(), it->size());
         if(!this->stream)
         {
             throw Exception("Could not write to stream");
         }
+        size += it->size();
 
         if(it != last_element_it)
         {
-            this->stream << "\\";
+            this->stream.put('\\');
             if(!this->stream)
             {
                 throw Exception("Could not write to stream");
             }
+            ++size;
         }
     }
-
-    auto const stream_end = this->stream.tellp();
-
-    if((stream_end-stream_begin)%2 == 1)
+    
+    if(size%2 == 1)
     {
         this->stream.put(padding);
         if(!this->stream)
@@ -634,4 +719,269 @@ Writer::Visitor
     }
 }
 
+void
+Writer::WriteVisitor
+::write_strings(Value::Integers const & sequence, char padding) const
+{
+    if(sequence.empty())
+    {
+        return;
+    }
+    
+    std::size_t size = 0;
+    
+    auto const last_element_it = --sequence.end();
+    for(auto it = sequence.begin(); it!= sequence.end(); ++it)
+    {
+        // IS is <= 12 bytes (PS 3.5, table 6.2-1)
+        char buffer[13];
+        auto const buffer_size = std::snprintf(buffer, 13, "%li", *it);
+        this->stream.write(buffer, buffer_size);
+        if(!this->stream)
+        {
+            throw Exception("Could not write to stream");
+        }
+        size += buffer_size;
+
+        if(it != last_element_it)
+        {
+            this->stream.put('\\');
+            if(!this->stream)
+            {
+                throw Exception("Could not write to stream");
+            }
+            ++size;
+        }
+    }
+
+    if(size%2 == 1)
+    {
+        this->stream.put(padding);
+        if(!this->stream)
+        {
+            throw Exception("Could not write to stream");
+        }
+    }
+}
+
+Writer::SizeVisitor
+::SizeVisitor(
+    VR vr, bool explicit_vr, ItemEncoding item_encoding, bool use_group_length)
+: vr(vr), explicit_vr(explicit_vr), item_encoding(item_encoding),
+    use_group_length(use_group_length)
+{
+    // Nothing else
+}
+
+Writer::SizeVisitor::result_type
+Writer::SizeVisitor
+::operator()(Value::Integers const & value) const
+{
+    if(this->vr == VR::IS)
+    {
+        std::size_t size=0;
+        
+        // Values
+        for(auto && x: value)
+        {
+            // IS uses a base-10 representation (PS 3.5, 6.2). For any positive
+            // integer x such that 10^n <= x < 10^(n+1), n+1 digits are required
+            // Since n <= log10(x) < n+1,
+            size += x==0 ? 1 : (1 + int(std::log10(std::abs(x))));
+            // No implicit '+' prefix is used for positive integers
+            if(x<0)
+            {
+                ++size;
+            }
+        }
+        
+        // Separators
+        if(!value.empty())
+        {
+            size += value.size()-1;
+        }
+        
+        // Padding
+        if(size%2 == 1)
+        {
+            ++size;
+        }
+        
+        return size;
+    }
+    else if(this->vr == VR::SV || this->vr == VR::UV)
+    {
+        return 8 * value.size();
+    }
+    else if(this->vr == VR::SL || this->vr == VR::UL)
+    {
+        return 4 * value.size();
+    }
+    else if(this->vr == VR::SS || this->vr == VR::US)
+    {
+        return 2 * value.size();
+    }
+    else
+    {
+        throw Exception("Cannot size " + as_string(this->vr));
+    }
+}
+
+Writer::SizeVisitor::result_type
+Writer::SizeVisitor
+::operator()(Value::Reals const & value) const
+{
+    if(this->vr == VR::DS)
+    {
+        std::size_t size=0;
+        
+        // Values: the size of the representation cannot be predicted, so we
+        // need to serialize each value
+        for(auto && x: value)
+        {
+            // Each item in the DS is at most 16 bytes (PS 3.5, 6.2), account
+            // for NUL at end
+            static unsigned int const buffer_size=16+1;
+            static char buffer[buffer_size];
+            write_ds(x, buffer, buffer_size);
+            size += strlen(buffer);
+        }
+        
+        // Separators
+        if(!value.empty())
+        {
+            size += value.size()-1;
+        }
+        
+        // Padding
+        if(size%2 == 1)
+        {
+            ++size;
+        }
+        
+        return size;
+    }
+    else if(this->vr == VR::FD)
+    {
+        return 8 * value.size();
+    }
+    else if(this->vr == VR::FL)
+    {
+        return 4 * value.size();
+    }
+    else
+    {
+        throw Exception("Cannot size " + as_string(this->vr));
+    }
+}
+
+Writer::SizeVisitor::result_type
+Writer::SizeVisitor
+::operator()(Value::Strings const & value) const
+{
+    if(this->vr == odil::VR::AT)
+    {
+        return 4*value.size();
+    }
+    else
+    {
+        std::size_t size=0;
+        
+        // Values
+        for(auto && x: value)
+        {
+            size += x.size();
+        }
+        
+        // Separators
+        if(!value.empty())
+        {
+            size += value.size()-1;
+        }
+        
+        // Padding
+        if(size%2 == 1)
+        {
+            ++size;
+        }
+        
+        return size;
+    }
+}
+
+Writer::SizeVisitor::result_type
+Writer::SizeVisitor
+::operator()(Value::DataSets const & value) const
+{
+    std::size_t size=0;
+    for(auto && x: value)
+    {
+        // Item tag
+        size += 4;
+        // Length
+        size += 4;
+        // Value
+        size += Writer::size(
+            *x, this->explicit_vr, this->item_encoding, this->use_group_length);
+        if(this->item_encoding == ItemEncoding::UndefinedLength)
+        {
+            // Item Delimitation Item tag
+            size += 4;
+            // "Length" of the delimitation item
+            size += 4;
+        }
+    }
+    
+    if(this->item_encoding == ItemEncoding::UndefinedLength)
+    {
+        // Sequence Delimitation Item tag
+        size += 4;
+        // "Length" of the delimitation item
+        size += 4;
+    }
+    
+    return size;
+}
+
+Writer::SizeVisitor::result_type
+Writer::SizeVisitor
+::operator()(Value::Binary const & value) const
+{
+    if(value.empty())
+    {
+        return 0;
+    }
+    else if(value.size() > 1)
+    {
+        std::size_t size = 0;
+        for(auto && fragment: value)
+        {
+            // Item tag
+            size += 4;
+            // Length
+            size += 4;
+            // Content
+            size += fragment.size();
+        }
+        // Sequence Delimitation Item tag
+        size += 4;
+        // "Length" of the empty final element
+        size += 4;
+        
+        return size;
+    }
+    else
+    {
+        std::size_t size = value[0].size();
+        
+        // Padding
+        if(size%2 == 1)
+        {
+            ++size;
+        }
+        
+        return size;
+    }
+}
+
 }
