@@ -24,7 +24,7 @@ namespace message
 CFindRequest
 ::CFindRequest(
     Value::Integer message_id, Value::String const & affected_sop_class_uid,
-    Value::Integer priority, DataSet const & dataset)
+    Value::Integer priority, std::shared_ptr<DataSet> dataset)
 : Request(message_id)
 {
     this->_create(affected_sop_class_uid, priority, dataset);
@@ -32,47 +32,23 @@ CFindRequest
 }
 
 CFindRequest
-::CFindRequest(
-    Value::Integer message_id, Value::String const & affected_sop_class_uid,
-    Value::Integer priority, DataSet && dataset)
-: Request(message_id)
-{
-    this->_create(affected_sop_class_uid, priority, dataset);
-    this->set_data_set(std::move(dataset));
-}
-
-CFindRequest
-::CFindRequest(Message const & message)
+::CFindRequest(std::shared_ptr<Message> message)
 : Request(message)
 {
     this->_parse(message);
-    this->set_data_set(message.get_data_set());
-}
-
-CFindRequest
-::CFindRequest(Message && message)
-: Request(message)
-{
-    this->_parse(message);
-    this->set_data_set(std::move(message.get_data_set()));
-}
-
-CFindRequest
-::~CFindRequest()
-{
-    // Nothing to do.
+    this->set_data_set(message->get_data_set());
 }
 
 void
 CFindRequest
 ::_create(
     Value::String const & affected_sop_class_uid, Value::Integer priority,
-    DataSet const & dataset)
+    std::shared_ptr<DataSet const> dataset)
 {
     this->set_command_field(Command::C_FIND_RQ);
     this->set_affected_sop_class_uid(affected_sop_class_uid);
     this->set_priority(priority);
-    if(dataset.empty())
+    if(!dataset || dataset->empty())
     {
         throw Exception("Data set is required");
     }
@@ -80,20 +56,20 @@ CFindRequest
 
 void
 CFindRequest
-::_parse(Message const & message)
+::_parse(std::shared_ptr<Message const> message)
 {
-    if(message.get_command_field() != Command::C_FIND_RQ)
+    if(!message || message->get_command_field() != Command::C_FIND_RQ)
     {
         throw Exception("Message is not a C-FIND-RQ");
     }
-    this->set_command_field(message.get_command_field());
+    this->set_command_field(message->get_command_field());
 
     this->set_affected_sop_class_uid(
-        message.get_command_set().as_string(registry::AffectedSOPClassUID, 0));
+        message->get_command_set()->as_string(registry::AffectedSOPClassUID, 0));
 
-    this->set_priority(message.get_command_set().as_int(registry::Priority, 0));
+    this->set_priority(message->get_command_set()->as_int(registry::Priority, 0));
 
-    if(!message.has_data_set() || message.get_data_set().empty())
+    if(!message->has_data_set() || message->get_data_set()->empty())
     {
         throw Exception("Data set is required");
     }
