@@ -31,7 +31,7 @@ CFindResponse
 CFindResponse
 ::CFindResponse(
     Value::Integer message_id_being_responded_to, Value::Integer status,
-    DataSet const & dataset)
+    std::shared_ptr<DataSet> dataset)
 : Response(message_id_being_responded_to, status)
 {
     this->set_command_field(Command::C_FIND_RSP);
@@ -39,57 +39,30 @@ CFindResponse
 }
 
 CFindResponse
-::CFindResponse(
-    Value::Integer message_id_being_responded_to, Value::Integer status,
-    DataSet && dataset)
-: Response(message_id_being_responded_to, status)
-{
-    this->set_command_field(Command::C_FIND_RSP);
-    this->set_data_set(std::move(dataset));
-}
-
-CFindResponse
-::CFindResponse(Message const & message)
+::CFindResponse(std::shared_ptr<Message> message)
 : Response(message)
 {
     this->_parse(message);
-    if(message.has_data_set())
+    if(message->has_data_set())
     {
-        this->set_data_set(message.get_data_set());
+        this->set_data_set(message->get_data_set());
     }
 }
 
-CFindResponse
-::CFindResponse(Message && message)
-: Response(message)
-{
-    this->_parse(message);
-    if(message.has_data_set())
-    {
-        this->set_data_set(std::move(message.get_data_set()));
-    }
-}
-
-CFindResponse
-::~CFindResponse()
-{
-    // Nothing to do.
-}
-
 void
 CFindResponse
-::_parse(Message const & message)
+::_parse(std::shared_ptr<Message const> message)
 {
-    if(message.get_command_field() != Command::C_FIND_RSP)
+    if(!message || message->get_command_field() != Command::C_FIND_RSP)
     {
         throw Exception("Message is not a C-FIND-RSP");
     }
-    this->set_command_field(message.get_command_field());
+    this->set_command_field(message->get_command_field());
 
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), message_id, registry::MessageID, as_int)
+        message->get_command_set(), message_id, registry::MessageID, as_int)
     ODIL_MESSAGE_SET_OPTIONAL_FIELD_MACRO(
-        message.get_command_set(), affected_sop_class_uid,
+        message->get_command_set(), affected_sop_class_uid,
         registry::AffectedSOPClassUID, as_string)
 }
 
