@@ -12,6 +12,7 @@
 #include <istream>
 #include <string>
 
+#include "odil/odil.h"
 #include "odil/pdu/Object.h"
 
 namespace odil
@@ -21,7 +22,7 @@ namespace pdu
 {
 
 /// @brief User Identity Sub-Item Structure (A-ASSOCIATE-AC) (PS 3.7, D.3.3.7.2).
-class UserIdentityAC: public Object
+class ODIL_API UserIdentityAC: public Object
 {
 public:
     /// @brief Item type.
