@@ -156,22 +156,44 @@ std::string const JPIPReferenced("1.2.840.10008.1.2.4.94");
 std::string const JPIPReferencedDeflate("1.2.840.10008.1.2.4.95");
 std::string const MPEG2MPML("1.2.840.10008.1.2.4.100");
 std::string const MPEG2MainProfileMainLevel("1.2.840.10008.1.2.4.100");
+std::string const MPEG2MPMLF("1.2.840.10008.1.2.4.100.1");
+std::string const FragmentableMPEG2MainProfileMainLevel("1.2.840.10008.1.2.4.100.1");
 std::string const MPEG2MPHL("1.2.840.10008.1.2.4.101");
 std::string const MPEG2MainProfileHighLevel("1.2.840.10008.1.2.4.101");
+std::string const MPEG2MPHLF("1.2.840.10008.1.2.4.101.1");
+std::string const FragmentableMPEG2MainProfileHighLevel("1.2.840.10008.1.2.4.101.1");
 std::string const MPEG4HP41("1.2.840.10008.1.2.4.102");
 std::string const MPEG4AVCH264HighProfileLevel41("1.2.840.10008.1.2.4.102");
+std::string const MPEG4HP41F("1.2.840.10008.1.2.4.102.1");
+std::string const FragmentableMPEG4AVCH264HighProfileLevel41("1.2.840.10008.1.2.4.102.1");
 std::string const MPEG4HP41BD("1.2.840.10008.1.2.4.103");
 std::string const MPEG4AVCH264BDcompatibleHighProfileLevel41("1.2.840.10008.1.2.4.103");
+std::string const MPEG4HP41BDF("1.2.840.10008.1.2.4.103.1");
+std::string const FragmentableMPEG4AVCH264BDcompatibleHighProfileLevel41("1.2.840.10008.1.2.4.103.1");
 std::string const MPEG4HP422D("1.2.840.10008.1.2.4.104");
 std::string const MPEG4AVCH264HighProfileLevel42For2DVideo("1.2.840.10008.1.2.4.104");
+std::string const MPEG4HP422DF("1.2.840.10008.1.2.4.104.1");
+std::string const FragmentableMPEG4AVCH264HighProfileLevel42For2DVideo("1.2.840.10008.1.2.4.104.1");
 std::string const MPEG4HP423D("1.2.840.10008.1.2.4.105");
 std::string const MPEG4AVCH264HighProfileLevel42For3DVideo("1.2.840.10008.1.2.4.105");
+std::string const MPEG4HP423DF("1.2.840.10008.1.2.4.105.1");
+std::string const FragmentableMPEG4AVCH264HighProfileLevel42For3DVideo("1.2.840.10008.1.2.4.105.1");
 std::string const MPEG4HP42STEREO("1.2.840.10008.1.2.4.106");
 std::string const MPEG4AVCH264StereoHighProfileLevel42("1.2.840.10008.1.2.4.106");
+std::string const MPEG4HP42STEREOF("1.2.840.10008.1.2.4.106.1");
+std::string const FragmentableMPEG4AVCH264StereoHighProfileLevel42("1.2.840.10008.1.2.4.106.1");
 std::string const HEVCMP51("1.2.840.10008.1.2.4.107");
 std::string const HEVCH265MainProfileLevel51("1.2.840.10008.1.2.4.107");
 std::string const HEVCM10P51("1.2.840.10008.1.2.4.108");
 std::string const HEVCH265Main10ProfileLevel51("1.2.840.10008.1.2.4.108");
+std::string const HTJ2KLossless("1.2.840.10008.1.2.4.201");
+std::string const HighThroughputJPEG2000ImageCompressionLosslessOnly("1.2.840.10008.1.2.4.201");
+std::string const HTJ2KLosslessRPCL("1.2.840.10008.1.2.4.202");
+std::string const HighThroughputJPEG2000withRPCLOptionsImageCompressionLosslessOnly("1.2.840.10008.1.2.4.202");
+std::string const HTJ2K("1.2.840.10008.1.2.4.203");
+std::string const HighThroughputJPEG2000ImageCompression("1.2.840.10008.1.2.4.203");
+std::string const JPIPHTJ2KReferenced("1.2.840.10008.1.2.4.204");
+std::string const JPIPHTJ2KReferencedDeflate("1.2.840.10008.1.2.4.205");
 std::string const RLELossless("1.2.840.10008.1.2.5");
 std::string const RFC2557MIMEEncapsulation("1.2.840.10008.1.2.6.1");
 std::string const RFC2557MIMEencapsulation_Retired("1.2.840.10008.1.2.6.1");
@@ -315,7 +337,7 @@ std::string const ImageOverlayBox("1.2.840.10008.5.1.1.24");
 std::string const ImageOverlayBoxSOPClass_Retired("1.2.840.10008.5.1.1.24");
 std::string const BasicPrintImageOverlayBox("1.2.840.10008.5.1.1.24.1");
 std::string const BasicPrintImageOverlayBoxSOPClass_Retired("1.2.840.10008.5.1.1.24.1");
-std::string const PrintQueue("1.2.840.10008.5.1.1.25");
+std::string const PrintQueueInstance("1.2.840.10008.5.1.1.25");
 std::string const PrintQueueSOPInstance_Retired("1.2.840.10008.5.1.1.25");
 std::string const PrintQueueManagement("1.2.840.10008.5.1.1.26");
 std::string const PrintQueueManagementSOPClass_Retired("1.2.840.10008.5.1.1.26");
@@ -360,6 +382,7 @@ std::string const UltrasoundImageStorageRetired("1.2.840.10008.5.1.4.1.1.6");
 std::string const UltrasoundImageStorage_Retired("1.2.840.10008.5.1.4.1.1.6");
 std::string const UltrasoundImageStorage("1.2.840.10008.5.1.4.1.1.6.1");
 std::string const EnhancedUSVolumeStorage("1.2.840.10008.5.1.4.1.1.6.2");
+std::string const PhotoacousticImageStorage("1.2.840.10008.5.1.4.1.1.6.3");
 std::string const SecondaryCaptureImageStorage("1.2.840.10008.5.1.4.1.1.7");
 std::string const MultiFrameSingleBitSecondaryCaptureImageStorage("1.2.840.10008.5.1.4.1.1.7.1");
 std::string const MultiframeSingleBitSecondaryCaptureImageStorage("1.2.840.10008.5.1.4.1.1.7.1");
@@ -378,6 +401,7 @@ std::string const WaveformStorageTrial_Retired("1.2.840.10008.5.1.4.1.1.9.1");
 std::string const TwelveLeadECGWaveformStorage("1.2.840.10008.5.1.4.1.1.9.1.1");
 std::string const GeneralECGWaveformStorage("1.2.840.10008.5.1.4.1.1.9.1.2");
 std::string const AmbulatoryECGWaveformStorage("1.2.840.10008.5.1.4.1.1.9.1.3");
+std::string const General32bitECGWaveformStorage("1.2.840.10008.5.1.4.1.1.9.1.4");
 std::string const HemodynamicWaveformStorage("1.2.840.10008.5.1.4.1.1.9.2.1");
 std::string const CardiacElectrophysiologyWaveformStorage("1.2.840.10008.5.1.4.1.1.9.3.1");
 std::string const BasicVoiceAudioWaveformStorage("1.2.840.10008.5.1.4.1.1.9.4.1");
@@ -405,6 +429,7 @@ std::string const AdvancedBlendingPresentationStateStorage("1.2.840.10008.5.1.4.
 std::string const VolumeRenderingVolumetricPresentationStateStorage("1.2.840.10008.5.1.4.1.1.11.9");
 std::string const SegmentedVolumeRenderingVolumetricPresentationStateStorage("1.2.840.10008.5.1.4.1.1.11.10");
 std::string const MultipleVolumeRenderingVolumetricPresentationStateStorage("1.2.840.10008.5.1.4.1.1.11.11");
+std::string const VariableModalityLUTSoftcopyPresentationStateStorage("1.2.840.10008.5.1.4.1.1.11.12");
 std::string const XRayAngiographicImageStorage("1.2.840.10008.5.1.4.1.1.12.1");
 std::string const EnhancedXAImageStorage("1.2.840.10008.5.1.4.1.1.12.1.1");
 std::string const XRayRadiofluoroscopicImageStorage("1.2.840.10008.5.1.4.1.1.12.2");
@@ -451,6 +476,8 @@ std::string const OphthalmicOpticalCoherenceTomographyEnFaceImageStorage("1.2.84
 std::string const OphthalmicOpticalCoherenceTomographyBscanVolumeAnalysisStorage("1.2.840.10008.5.1.4.1.1.77.1.5.8");
 std::string const VLWholeSlideMicroscopyImageStorage("1.2.840.10008.5.1.4.1.1.77.1.6");
 std::string const DermoscopicPhotographyImageStorage("1.2.840.10008.5.1.4.1.1.77.1.7");
+std::string const ConfocalMicroscopyImageStorage("1.2.840.10008.5.1.4.1.1.77.1.8");
+std::string const ConfocalMicroscopyTiledPyramidalImageStorage("1.2.840.10008.5.1.4.1.1.77.1.9");
 std::string const LensometryMeasurementsStorage("1.2.840.10008.5.1.4.1.1.78.1");
 std::string const AutorefractionMeasurementsStorage("1.2.840.10008.5.1.4.1.1.78.2");
 std::string const KeratometryMeasurementsStorage("1.2.840.10008.5.1.4.1.1.78.3");
@@ -515,6 +542,17 @@ std::string const ProtocolApprovalInformationModelGet("1.2.840.10008.5.1.4.1.1.2
 std::string const ProtocolApprovalInformationModelGET("1.2.840.10008.5.1.4.1.1.200.6");
 std::string const XADefinedProcedureProtocolStorage("1.2.840.10008.5.1.4.1.1.200.7");
 std::string const XAPerformedProcedureProtocolStorage("1.2.840.10008.5.1.4.1.1.200.8");
+std::string const InventoryStorage("1.2.840.10008.5.1.4.1.1.201.1");
+std::string const InventoryFind("1.2.840.10008.5.1.4.1.1.201.2");
+std::string const InventoryFIND("1.2.840.10008.5.1.4.1.1.201.2");
+std::string const InventoryMove("1.2.840.10008.5.1.4.1.1.201.3");
+std::string const InventoryMOVE("1.2.840.10008.5.1.4.1.1.201.3");
+std::string const InventoryGet("1.2.840.10008.5.1.4.1.1.201.4");
+std::string const InventoryGET("1.2.840.10008.5.1.4.1.1.201.4");
+std::string const InventoryCreation("1.2.840.10008.5.1.4.1.1.201.5");
+std::string const RepositoryQuery("1.2.840.10008.5.1.4.1.1.201.6");
+std::string const StorageManagementInstance("1.2.840.10008.5.1.4.1.1.201.1.1");
+std::string const StorageManagementSOPInstance("1.2.840.10008.5.1.4.1.1.201.1.1");
 std::string const RTImageStorage("1.2.840.10008.5.1.4.1.1.481.1");
 std::string const RTDoseStorage("1.2.840.10008.5.1.4.1.1.481.2");
 std::string const RTStructureSetStorage("1.2.840.10008.5.1.4.1.1.481.3");
@@ -537,6 +575,9 @@ std::string const CArmPhotonElectronRadiationRecordStorage("1.2.840.10008.5.1.4.
 std::string const RoboticRadiationRecordStorage("1.2.840.10008.5.1.4.1.1.481.20");
 std::string const RTRadiationSetDeliveryInstructionStorage("1.2.840.10008.5.1.4.1.1.481.21");
 std::string const RTTreatmentPreparationStorage("1.2.840.10008.5.1.4.1.1.481.22");
+std::string const EnhancedRTImageStorage("1.2.840.10008.5.1.4.1.1.481.23");
+std::string const EnhancedContinuousRTImageStorage("1.2.840.10008.5.1.4.1.1.481.24");
+std::string const RTPatientPositionAcquisitionInstructionStorage("1.2.840.10008.5.1.4.1.1.481.25");
 std::string const DICOSCTImageStorage("1.2.840.10008.5.1.4.1.1.501.1");
 std::string const DICOSDigitalXRayImageStorageForPresentation("1.2.840.10008.5.1.4.1.1.501.2.1");
 std::string const DICOSDigitalXRayImageStorageForProcessing("1.2.840.10008.5.1.4.1.1.501.2.2");
