@@ -129,6 +129,48 @@ void update_0008(
     public_dictionary.emplace(Tag(0x0008, 0x030e), ElementsDictionaryEntry("Private Data Element Description", "PrivateDataElementDescription",  "UT", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x030f), ElementsDictionaryEntry("Private Data Element Encoding", "PrivateDataElementEncoding",  "UT", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x0310), ElementsDictionaryEntry("Private Data Element Definition Sequence", "PrivateDataElementDefinitionSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0400), ElementsDictionaryEntry("Scope of Inventory Sequence", "ScopeOfInventorySequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0401), ElementsDictionaryEntry("Inventory Purpose", "InventoryPurpose",  "LT", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0402), ElementsDictionaryEntry("Inventory Instance Description", "InventoryInstanceDescription",  "LT", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0403), ElementsDictionaryEntry("Inventory Level", "InventoryLevel",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0404), ElementsDictionaryEntry("Item Inventory DateTime", "ItemInventoryDateTime",  "DT", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0405), ElementsDictionaryEntry("Removed from Operational Use", "RemovedFromOperationalUse",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0406), ElementsDictionaryEntry("Reason for Removal Code Sequence", "ReasonForRemovalCodeSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0407), ElementsDictionaryEntry("Stored Instance Base URI", "StoredInstanceBaseURI",  "UR", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0408), ElementsDictionaryEntry("Folder Access URI", "FolderAccessURI",  "UR", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0409), ElementsDictionaryEntry("File Access URI", "FileAccessURI",  "UR", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x040a), ElementsDictionaryEntry("Container File Type", "ContainerFileType",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x040b), ElementsDictionaryEntry("Filename in Container", "FilenameInContainer",  "UR", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x040c), ElementsDictionaryEntry("File Offset in Container", "FileOffsetInContainer",  "UV", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x040d), ElementsDictionaryEntry("File Length in Container", "FileLengthInContainer",  "UV", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x040e), ElementsDictionaryEntry("Stored Instance Transfer Syntax UID", "StoredInstanceTransferSyntaxUID",  "UI", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x040f), ElementsDictionaryEntry("Extended Matching Mechanisms", "ExtendedMatchingMechanisms",  "CS", "1-n"));
+    public_dictionary.emplace(Tag(0x0008, 0x0410), ElementsDictionaryEntry("Range Matching Sequence", "RangeMatchingSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0411), ElementsDictionaryEntry("List of UID Matching Sequence", "ListOfUIDMatchingSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0412), ElementsDictionaryEntry("Empty Value Matching Sequence", "EmptyValueMatchingSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0413), ElementsDictionaryEntry("General Matching Sequence", "GeneralMatchingSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0414), ElementsDictionaryEntry("Requested Status Interval", "RequestedStatusInterval",  "US", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0415), ElementsDictionaryEntry("Retain Instances", "RetainInstances",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0416), ElementsDictionaryEntry("Expiration DateTime", "ExpirationDateTime",  "DT", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0417), ElementsDictionaryEntry("Transaction Status", "TransactionStatus",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0418), ElementsDictionaryEntry("Transaction Status Comment", "TransactionStatusComment",  "LT", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0419), ElementsDictionaryEntry("File Set Access Sequence", "FileSetAccessSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x041a), ElementsDictionaryEntry("File Access Sequence", "FileAccessSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x041b), ElementsDictionaryEntry("Record Key", "RecordKey",  "OB", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x041c), ElementsDictionaryEntry("Prior Record Key", "PriorRecordKey",  "OB", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x041d), ElementsDictionaryEntry("Metadata Sequence", "MetadataSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x041e), ElementsDictionaryEntry("Updated Metadata Sequence", "UpdatedMetadataSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x041f), ElementsDictionaryEntry("Study Update DateTime", "StudyUpdateDateTime",  "DT", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0420), ElementsDictionaryEntry("Inventory Access End Points Sequence", "InventoryAccessEndPointsSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0421), ElementsDictionaryEntry("Study Access End Points Sequence", "StudyAccessEndPointsSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0422), ElementsDictionaryEntry("Incorporated Inventory Instance Sequence", "IncorporatedInventoryInstanceSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0423), ElementsDictionaryEntry("Inventoried Studies Sequence", "InventoriedStudiesSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0424), ElementsDictionaryEntry("Inventoried Series Sequence", "InventoriedSeriesSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0425), ElementsDictionaryEntry("Inventoried Instances Sequence", "InventoriedInstancesSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0426), ElementsDictionaryEntry("Inventory Completion Status", "InventoryCompletionStatus",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0427), ElementsDictionaryEntry("Number of Study Records in Instance", "NumberOfStudyRecordsInInstance",  "UL", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0428), ElementsDictionaryEntry("Total Number of Study Records", "TotalNumberOfStudyRecords",  "UV", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x0429), ElementsDictionaryEntry("Maximum Number of Records", "MaximumNumberOfRecords",  "UV", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1000), ElementsDictionaryEntry("Network ID", "NetworkID",  "AE", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1010), ElementsDictionaryEntry("Station Name", "StationName",  "SH", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1030), ElementsDictionaryEntry("Study Description", "StudyDescription",  "LO", "1"));
@@ -152,6 +194,7 @@ void update_0008(
     public_dictionary.emplace(Tag(0x0008, 0x1100), ElementsDictionaryEntry("Referenced Results Sequence", "ReferencedResultsSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1110), ElementsDictionaryEntry("Referenced Study Sequence", "ReferencedStudySequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1111), ElementsDictionaryEntry("Referenced Performed Procedure Step Sequence", "ReferencedPerformedProcedureStepSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x1112), ElementsDictionaryEntry("Referenced Instances by SOP Class Sequence", "ReferencedInstancesBySOPClassSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1115), ElementsDictionaryEntry("Referenced Series Sequence", "ReferencedSeriesSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1120), ElementsDictionaryEntry("Referenced Patient Sequence", "ReferencedPatientSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1125), ElementsDictionaryEntry("Referenced Visit Sequence", "ReferencedVisitSequence",  "SQ", "1"));
@@ -179,6 +222,7 @@ void update_0008(
     public_dictionary.emplace(Tag(0x0008, 0x1198), ElementsDictionaryEntry("Failed SOP Sequence", "FailedSOPSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1199), ElementsDictionaryEntry("Referenced SOP Sequence", "ReferencedSOPSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x119a), ElementsDictionaryEntry("Other Failures Sequence", "OtherFailuresSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0008, 0x119b), ElementsDictionaryEntry("Failed Study Sequence", "FailedStudySequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1200), ElementsDictionaryEntry("Studies Containing Other Referenced Instances Sequence", "StudiesContainingOtherReferencedInstancesSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x1250), ElementsDictionaryEntry("Related Series Sequence", "RelatedSeriesSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x2110), ElementsDictionaryEntry("Lossy Image Compression (Retired)", "LossyImageCompressionRetired",  "CS", "1"));
@@ -226,7 +270,7 @@ void update_0008(
     public_dictionary.emplace(Tag(0x0008, 0x3011), ElementsDictionaryEntry("Source Irradiation Event Sequence", "SourceIrradiationEventSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x3012), ElementsDictionaryEntry("Radiopharmaceutical Administration Event UID", "RadiopharmaceuticalAdministrationEventUID",  "UI", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x4000), ElementsDictionaryEntry("Identifying Comments", "IdentifyingComments",  "LT", "1"));
-    public_dictionary.emplace(Tag(0x0008, 0x9007), ElementsDictionaryEntry("Frame Type", "FrameType",  "CS", "4"));
+    public_dictionary.emplace(Tag(0x0008, 0x9007), ElementsDictionaryEntry("Frame Type", "FrameType",  "CS", "4-5"));
     public_dictionary.emplace(Tag(0x0008, 0x9092), ElementsDictionaryEntry("Referenced Image Evidence Sequence", "ReferencedImageEvidenceSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x9121), ElementsDictionaryEntry("Referenced Raw Data Sequence", "ReferencedRawDataSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0008, 0x9123), ElementsDictionaryEntry("Creator-Version UID", "CreatorVersionUID",  "UI", "1"));
@@ -349,6 +393,48 @@ void update_0008(
     public_tags.emplace("PrivateDataElementDescription", Tag(0x0008, 0x030e));
     public_tags.emplace("PrivateDataElementEncoding", Tag(0x0008, 0x030f));
     public_tags.emplace("PrivateDataElementDefinitionSequence", Tag(0x0008, 0x0310));
+    public_tags.emplace("ScopeOfInventorySequence", Tag(0x0008, 0x0400));
+    public_tags.emplace("InventoryPurpose", Tag(0x0008, 0x0401));
+    public_tags.emplace("InventoryInstanceDescription", Tag(0x0008, 0x0402));
+    public_tags.emplace("InventoryLevel", Tag(0x0008, 0x0403));
+    public_tags.emplace("ItemInventoryDateTime", Tag(0x0008, 0x0404));
+    public_tags.emplace("RemovedFromOperationalUse", Tag(0x0008, 0x0405));
+    public_tags.emplace("ReasonForRemovalCodeSequence", Tag(0x0008, 0x0406));
+    public_tags.emplace("StoredInstanceBaseURI", Tag(0x0008, 0x0407));
+    public_tags.emplace("FolderAccessURI", Tag(0x0008, 0x0408));
+    public_tags.emplace("FileAccessURI", Tag(0x0008, 0x0409));
+    public_tags.emplace("ContainerFileType", Tag(0x0008, 0x040a));
+    public_tags.emplace("FilenameInContainer", Tag(0x0008, 0x040b));
+    public_tags.emplace("FileOffsetInContainer", Tag(0x0008, 0x040c));
+    public_tags.emplace("FileLengthInContainer", Tag(0x0008, 0x040d));
+    public_tags.emplace("StoredInstanceTransferSyntaxUID", Tag(0x0008, 0x040e));
+    public_tags.emplace("ExtendedMatchingMechanisms", Tag(0x0008, 0x040f));
+    public_tags.emplace("RangeMatchingSequence", Tag(0x0008, 0x0410));
+    public_tags.emplace("ListOfUIDMatchingSequence", Tag(0x0008, 0x0411));
+    public_tags.emplace("EmptyValueMatchingSequence", Tag(0x0008, 0x0412));
+    public_tags.emplace("GeneralMatchingSequence", Tag(0x0008, 0x0413));
+    public_tags.emplace("RequestedStatusInterval", Tag(0x0008, 0x0414));
+    public_tags.emplace("RetainInstances", Tag(0x0008, 0x0415));
+    public_tags.emplace("ExpirationDateTime", Tag(0x0008, 0x0416));
+    public_tags.emplace("TransactionStatus", Tag(0x0008, 0x0417));
+    public_tags.emplace("TransactionStatusComment", Tag(0x0008, 0x0418));
+    public_tags.emplace("FileSetAccessSequence", Tag(0x0008, 0x0419));
+    public_tags.emplace("FileAccessSequence", Tag(0x0008, 0x041a));
+    public_tags.emplace("RecordKey", Tag(0x0008, 0x041b));
+    public_tags.emplace("PriorRecordKey", Tag(0x0008, 0x041c));
+    public_tags.emplace("MetadataSequence", Tag(0x0008, 0x041d));
+    public_tags.emplace("UpdatedMetadataSequence", Tag(0x0008, 0x041e));
+    public_tags.emplace("StudyUpdateDateTime", Tag(0x0008, 0x041f));
+    public_tags.emplace("InventoryAccessEndPointsSequence", Tag(0x0008, 0x0420));
+    public_tags.emplace("StudyAccessEndPointsSequence", Tag(0x0008, 0x0421));
+    public_tags.emplace("IncorporatedInventoryInstanceSequence", Tag(0x0008, 0x0422));
+    public_tags.emplace("InventoriedStudiesSequence", Tag(0x0008, 0x0423));
+    public_tags.emplace("InventoriedSeriesSequence", Tag(0x0008, 0x0424));
+    public_tags.emplace("InventoriedInstancesSequence", Tag(0x0008, 0x0425));
+    public_tags.emplace("InventoryCompletionStatus", Tag(0x0008, 0x0426));
+    public_tags.emplace("NumberOfStudyRecordsInInstance", Tag(0x0008, 0x0427));
+    public_tags.emplace("TotalNumberOfStudyRecords", Tag(0x0008, 0x0428));
+    public_tags.emplace("MaximumNumberOfRecords", Tag(0x0008, 0x0429));
     public_tags.emplace("NetworkID", Tag(0x0008, 0x1000));
     public_tags.emplace("StationName", Tag(0x0008, 0x1010));
     public_tags.emplace("StudyDescription", Tag(0x0008, 0x1030));
@@ -372,6 +458,7 @@ void update_0008(
     public_tags.emplace("ReferencedResultsSequence", Tag(0x0008, 0x1100));
     public_tags.emplace("ReferencedStudySequence", Tag(0x0008, 0x1110));
     public_tags.emplace("ReferencedPerformedProcedureStepSequence", Tag(0x0008, 0x1111));
+    public_tags.emplace("ReferencedInstancesBySOPClassSequence", Tag(0x0008, 0x1112));
     public_tags.emplace("ReferencedSeriesSequence", Tag(0x0008, 0x1115));
     public_tags.emplace("ReferencedPatientSequence", Tag(0x0008, 0x1120));
     public_tags.emplace("ReferencedVisitSequence", Tag(0x0008, 0x1125));
@@ -399,6 +486,7 @@ void update_0008(
     public_tags.emplace("FailedSOPSequence", Tag(0x0008, 0x1198));
     public_tags.emplace("ReferencedSOPSequence", Tag(0x0008, 0x1199));
     public_tags.emplace("OtherFailuresSequence", Tag(0x0008, 0x119a));
+    public_tags.emplace("FailedStudySequence", Tag(0x0008, 0x119b));
     public_tags.emplace("StudiesContainingOtherReferencedInstancesSequence", Tag(0x0008, 0x1200));
     public_tags.emplace("RelatedSeriesSequence", Tag(0x0008, 0x1250));
     public_tags.emplace("LossyImageCompressionRetired", Tag(0x0008, 0x2110));
