@@ -48,6 +48,14 @@ void update_0014(
     public_dictionary.emplace(Tag(0x0014, 0x0106), ElementsDictionaryEntry("Multiple Component Approval Sequence", "MultipleComponentApprovalSequence",  "SQ", "1"));
     public_dictionary.emplace(Tag(0x0014, 0x0107), ElementsDictionaryEntry("Other Approval Status", "OtherApprovalStatus",  "CS", "1-n"));
     public_dictionary.emplace(Tag(0x0014, 0x0108), ElementsDictionaryEntry("Other Secondary Approval Status", "OtherSecondaryApprovalStatus",  "CS", "1-n"));
+    public_dictionary.emplace(Tag(0x0014, 0x0200), ElementsDictionaryEntry("Data Element Label Sequence", "DataElementLabelSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0201), ElementsDictionaryEntry("Data Element Label Item Sequence", "DataElementLabelItemSequence",  "SQ", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0202), ElementsDictionaryEntry("Data Element", "DataElement",  "AT", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0203), ElementsDictionaryEntry("Data Element Name", "DataElementName",  "LO", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0204), ElementsDictionaryEntry("Data Element Description", "DataElementDescription",  "LO", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0205), ElementsDictionaryEntry("Data Element Conditionality", "DataElementConditionality",  "CS", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0206), ElementsDictionaryEntry("Data Element Minimum Characters", "DataElementMinimumCharacters",  "IS", "1"));
+    public_dictionary.emplace(Tag(0x0014, 0x0207), ElementsDictionaryEntry("Data Element Maximum Characters", "DataElementMaximumCharacters",  "IS", "1"));
     public_dictionary.emplace(Tag(0x0014, 0x1010), ElementsDictionaryEntry("Actual Environmental Conditions", "ActualEnvironmentalConditions",  "ST", "1"));
     public_dictionary.emplace(Tag(0x0014, 0x1020), ElementsDictionaryEntry("Expiry Date", "ExpiryDate",  "DA", "1"));
     public_dictionary.emplace(Tag(0x0014, 0x1040), ElementsDictionaryEntry("Environmental Conditions", "EnvironmentalConditions",  "ST", "1"));
@@ -243,6 +251,14 @@ void update_0014(
     public_tags.emplace("MultipleComponentApprovalSequence", Tag(0x0014, 0x0106));
     public_tags.emplace("OtherApprovalStatus", Tag(0x0014, 0x0107));
     public_tags.emplace("OtherSecondaryApprovalStatus", Tag(0x0014, 0x0108));
+    public_tags.emplace("DataElementLabelSequence", Tag(0x0014, 0x0200));
+    public_tags.emplace("DataElementLabelItemSequence", Tag(0x0014, 0x0201));
+    public_tags.emplace("DataElement", Tag(0x0014, 0x0202));
+    public_tags.emplace("DataElementName", Tag(0x0014, 0x0203));
+    public_tags.emplace("DataElementDescription", Tag(0x0014, 0x0204));
+    public_tags.emplace("DataElementConditionality", Tag(0x0014, 0x0205));
+    public_tags.emplace("DataElementMinimumCharacters", Tag(0x0014, 0x0206));
+    public_tags.emplace("DataElementMaximumCharacters", Tag(0x0014, 0x0207));
     public_tags.emplace("ActualEnvironmentalConditions", Tag(0x0014, 0x1010));
     public_tags.emplace("ExpiryDate", Tag(0x0014, 0x1020));
     public_tags.emplace("EnvironmentalConditions", Tag(0x0014, 0x1040));
