@@ -44,6 +44,14 @@ Tag const RepairID(0x0014, 0x0105);
 Tag const MultipleComponentApprovalSequence(0x0014, 0x0106);
 Tag const OtherApprovalStatus(0x0014, 0x0107);
 Tag const OtherSecondaryApprovalStatus(0x0014, 0x0108);
+Tag const DataElementLabelSequence(0x0014, 0x0200);
+Tag const DataElementLabelItemSequence(0x0014, 0x0201);
+Tag const DataElement(0x0014, 0x0202);
+Tag const DataElementName(0x0014, 0x0203);
+Tag const DataElementDescription(0x0014, 0x0204);
+Tag const DataElementConditionality(0x0014, 0x0205);
+Tag const DataElementMinimumCharacters(0x0014, 0x0206);
+Tag const DataElementMaximumCharacters(0x0014, 0x0207);
 Tag const ActualEnvironmentalConditions(0x0014, 0x1010);
 Tag const ExpiryDate(0x0014, 0x1020);
 Tag const EnvironmentalConditions(0x0014, 0x1040);
