@@ -213,6 +213,8 @@ Tag const DateOfLastCalibration(0x0018, 0x1200);
 Tag const TimeOfLastCalibration(0x0018, 0x1201);
 Tag const DateTimeOfLastCalibration(0x0018, 0x1202);
 Tag const CalibrationDateTime(0x0018, 0x1203);
+Tag const DateOfManufacture(0x0018, 0x1204);
+Tag const DateOfInstallation(0x0018, 0x1205);
 Tag const ConvolutionKernel(0x0018, 0x1210);
 Tag const UpperLowerPixelValues(0x0018, 0x1240);
 Tag const ActualFrameDuration(0x0018, 0x1242);
@@ -830,6 +832,27 @@ Tag const TransducerGeometryCodeSequence(0x0018, 0x980d);
 Tag const TransducerBeamSteeringCodeSequence(0x0018, 0x980e);
 Tag const TransducerApplicationCodeSequence(0x0018, 0x980f);
 Tag const ZeroVelocityPixelValue(0x0018, 0x9810);
+Tag const PhotoacousticExcitationCharacteristicsSequence(0x0018, 0x9821);
+Tag const ExcitationSpectralWidth(0x0018, 0x9822);
+Tag const ExcitationEnergy(0x0018, 0x9823);
+Tag const ExcitationPulseDuration(0x0018, 0x9824);
+Tag const ExcitationWavelengthSequence(0x0018, 0x9825);
+Tag const ExcitationWavelength(0x0018, 0x9826);
+Tag const IlluminationTranslationFlag(0x0018, 0x9828);
+Tag const AcousticCouplingMediumFlag(0x0018, 0x9829);
+Tag const AcousticCouplingMediumCodeSequence(0x0018, 0x982a);
+Tag const AcousticCouplingMediumTemperature(0x0018, 0x982b);
+Tag const TransducerResponseSequence(0x0018, 0x982c);
+Tag const CenterFrequency(0x0018, 0x982d);
+Tag const FractionalBandwidth(0x0018, 0x982e);
+Tag const LowerCutoffFrequency(0x0018, 0x982f);
+Tag const UpperCutoffFrequency(0x0018, 0x9830);
+Tag const TransducerTechnologySequence(0x0018, 0x9831);
+Tag const SoundSpeedCorrectionMechanismCodeSequence(0x0018, 0x9832);
+Tag const ObjectSoundSpeed(0x0018, 0x9833);
+Tag const AcousticCouplingMediumSoundSpeed(0x0018, 0x9834);
+Tag const PhotoacousticImageFrameTypeSequence(0x0018, 0x9835);
+Tag const ImageDataTypeCodeSequence(0x0018, 0x9836);
 Tag const ReferenceLocationLabel(0x0018, 0x9900);
 Tag const ReferenceLocationDescription(0x0018, 0x9901);
 Tag const ReferenceBasisCodeSequence(0x0018, 0x9902);
