@@ -65,6 +65,24 @@ Tag const ImpedanceValue(0x003a, 0x0313);
 Tag const ImpedanceMeasurementDateTime(0x003a, 0x0314);
 Tag const ImpedanceMeasurementFrequency(0x003a, 0x0315);
 Tag const ImpedanceMeasurementCurrentType(0x003a, 0x0316);
+Tag const WaveformAmplifierType(0x003a, 0x0317);
+Tag const FilterLowFrequencyCharacteristicsSequence(0x003a, 0x0318);
+Tag const FilterHighFrequencyCharacteristicsSequence(0x003a, 0x0319);
+Tag const SummarizedFilterLookupTable(0x003a, 0x0320);
+Tag const NotchFilterCharacteristicsSequence(0x003a, 0x0321);
+Tag const WaveformFilterType(0x003a, 0x0322);
+Tag const AnalogFilterCharacteristicsSequence(0x003a, 0x0323);
+Tag const AnalogFilterRollOff(0x003a, 0x0324);
+Tag const AnalogFilterType(0x003a, 0x0325);
+Tag const DigitalFilterCharacteristicsSequence(0x003a, 0x0326);
+Tag const DigitalFilterOrder(0x003a, 0x0327);
+Tag const DigitalFilterTypeCodeSequence(0x003a, 0x0328);
+Tag const WaveformFilterDescription(0x003a, 0x0329);
+Tag const FilterLookupTableSequence(0x003a, 0x032a);
+Tag const FilterLookupTableDescription(0x003a, 0x032b);
+Tag const FrequencyEncodingCodeSequence(0x003a, 0x032c);
+Tag const MagnitudeEncodingCodeSequence(0x003a, 0x032d);
+Tag const FilterLookupTableData(0x003a, 0x032e);
 
 }
 
