@@ -221,6 +221,7 @@ Tag const VerifyingOrganization(0x0040, 0xa027);
 Tag const DocumentingOrganizationIdentifierCodeSequenceTrial(0x0040, 0xa028);
 Tag const VerificationDateTime(0x0040, 0xa030);
 Tag const ObservationDateTime(0x0040, 0xa032);
+Tag const ObservationStartDateTime(0x0040, 0xa033);
 Tag const ValueType(0x0040, 0xa040);
 Tag const ConceptNameCodeSequence(0x0040, 0xa043);
 Tag const MeasurementPrecisionDescriptionTrial(0x0040, 0xa047);
@@ -318,7 +319,7 @@ Tag const RelationshipTypeCodeSequenceTrial(0x0040, 0xa732);
 Tag const LanguageCodeSequenceTrial(0x0040, 0xa744);
 Tag const TabulatedValuesSequence(0x0040, 0xa801);
 Tag const NumberOfTableRows(0x0040, 0xa802);
-Tag const NumbeOfTableColumns(0x0040, 0xa803);
+Tag const NumberOfTableColumns(0x0040, 0xa803);
 Tag const TableRowNumber(0x0040, 0xa804);
 Tag const TableColumnNumber(0x0040, 0xa805);
 Tag const TableRowDefinitionSequence(0x0040, 0xa806);
