@@ -37,6 +37,8 @@ Tag const ROIName(0x3006, 0x0026);
 Tag const ROIDescription(0x3006, 0x0028);
 Tag const ROIDisplayColor(0x3006, 0x002a);
 Tag const ROIVolume(0x3006, 0x002c);
+Tag const ROIDateTime(0x3006, 0x002d);
+Tag const ROIObservationDateTime(0x3006, 0x002e);
 Tag const RTRelatedROISequence(0x3006, 0x0030);
 Tag const RTROIRelationship(0x3006, 0x0033);
 Tag const ROIGenerationAlgorithm(0x3006, 0x0036);
@@ -51,6 +53,11 @@ Tag const NumberOfContourPoints(0x3006, 0x0046);
 Tag const ContourNumber(0x3006, 0x0048);
 Tag const AttachedContours(0x3006, 0x0049);
 Tag const SourcePixelPlanesCharacteristicsSequence(0x3006, 0x004a);
+Tag const SourceSeriesSequence(0x3006, 0x004b);
+Tag const SourceSeriesInformationSequence(0x3006, 0x004c);
+Tag const ROICreatorSequence(0x3006, 0x004d);
+Tag const ROIInterpreterSequence(0x3006, 0x004e);
+Tag const ROIObservationContextCodeSequence(0x3006, 0x004f);
 Tag const ContourData(0x3006, 0x0050);
 Tag const RTROIObservationsSequence(0x3006, 0x0080);
 Tag const ObservationNumber(0x3006, 0x0082);
