@@ -73,6 +73,10 @@ Tag const ReferencedMeasuredDoseReferenceNumber(0x3008, 0x0082);
 Tag const ReferencedCalculatedDoseReferenceSequence(0x3008, 0x0090);
 Tag const ReferencedCalculatedDoseReferenceNumber(0x3008, 0x0092);
 Tag const BeamLimitingDeviceLeafPairsSequence(0x3008, 0x00a0);
+Tag const EnhancedRTBeamLimitingDeviceSequence(0x3008, 0x00a1);
+Tag const EnhancedRTBeamLimitingOpeningSequence(0x3008, 0x00a2);
+Tag const EnhancedRTBeamLimitingDeviceDefinitionFlag(0x3008, 0x00a3);
+Tag const ParallelRTBeamDelimiterOpeningExtents(0x3008, 0x00a4);
 Tag const RecordedWedgeSequence(0x3008, 0x00b0);
 Tag const RecordedCompensatorSequence(0x3008, 0x00c0);
 Tag const RecordedBlockSequence(0x3008, 0x00d0);
