@@ -26,6 +26,7 @@ void update_7fe0(
 
     public_dictionary.emplace(Tag(0x7fe0, 0x0001), ElementsDictionaryEntry("Extended Offset Table", "ExtendedOffsetTable",  "OV", "1"));
     public_dictionary.emplace(Tag(0x7fe0, 0x0002), ElementsDictionaryEntry("Extended Offset Table Lengths", "ExtendedOffsetTableLengths",  "OV", "1"));
+    public_dictionary.emplace(Tag(0x7fe0, 0x0003), ElementsDictionaryEntry("Encapsulated Pixel Data Value Total Length", "EncapsulatedPixelDataValueTotalLength",  "UV", "1"));
     public_dictionary.emplace(Tag(0x7fe0, 0x0008), ElementsDictionaryEntry("Float Pixel Data", "FloatPixelData",  "OF", "1"));
     public_dictionary.emplace(Tag(0x7fe0, 0x0009), ElementsDictionaryEntry("Double Float Pixel Data", "DoubleFloatPixelData",  "OD", "1"));
     public_dictionary.emplace(Tag(0x7fe0, 0x0010), ElementsDictionaryEntry("Pixel Data", "PixelData",  "OB or OW", "1"));
@@ -35,6 +36,7 @@ void update_7fe0(
 
     public_tags.emplace("ExtendedOffsetTable", Tag(0x7fe0, 0x0001));
     public_tags.emplace("ExtendedOffsetTableLengths", Tag(0x7fe0, 0x0002));
+    public_tags.emplace("EncapsulatedPixelDataValueTotalLength", Tag(0x7fe0, 0x0003));
     public_tags.emplace("FloatPixelData", Tag(0x7fe0, 0x0008));
     public_tags.emplace("DoubleFloatPixelData", Tag(0x7fe0, 0x0009));
     public_tags.emplace("PixelData", Tag(0x7fe0, 0x0010));
