@@ -10,6 +10,9 @@
 
 #include "odil/FindSCU.h"
 
+#include "opaque_types.h"
+#include "type_casters.h"
+
 namespace
 {
 
